colour.characterisation.dataset.colour_checkers.chromaticity_coordinates Module — Colour 0.3.0 documentation

# colour.characterisation.dataset.colour_checkers.chromaticity_coordinates Module

## ColourCheckers Chromaticity Coordinates

Defines ColourCheckers chromaticity coordinates in CIE xyY colourspace.

Each ColourChecker data is in the form of a list of 24 namedtuples as follows:

    [('index', 'name', 'x', 'y', 'Y'), ..., ('index', 'name', 'x', 'y', 'Y')]

The following ColourCheckers data is available:

- `BABELCOLOR_AVERAGE`: Average data derived from measurements of 30 ColourChecker charts.
- `COLORCHECKER_2005`: Reference data from GretagMacbeth published in 2005.
- `COLORCHECKER_1976`: ColourChecker developed by McCamy and Al. at Macbeth, a Division of Kollmorgen.

See also

Colour Fitting IPython Notebook

References

[1] | http://www.babelcolor.com/download/ColorChecker_RGB_and_spectra.xls (Last accessed 24 February 2014)

[2] | http://www.babelcolor.com/main_level/ColorChecker.htm

`colour.characterisation.dataset.colour_checkers.chromaticity_coordinates.` `COLOURCHECKER_INXYY`

  alias of `ColourChecker_InxxY`

`colour.characterisation.dataset.colour_checkers.chromaticity_coordinates.` `COLOURCHECKER`

  alias of `ColourChecker`

`colour.characterisation.dataset.colour_checkers.chromaticity_coordinates.` `BABELCOLOR_AVERAGE_ILLUMINANT` = (0.34567, 0.3585)

  BabelColor Average illuminant.

  BABELCOLOR_AVERAGE_ILLUMINANT : tuple

`colour.characterisation.dataset.colour_checkers.chromaticity_coordinates.` `BABELCOLOR_AVERAGE` = [ColourChecker_InxxY(index=1, name=u'dark skin', x=0.4325, y=0.3788, Y=0.1034), ColourChecker_InxxY(index=2, name=u'light skin', x=0.4191, y=0.3748, Y=0.3525), ColourChecker_InxxY(index=3, name=u'blue sky', x=0.2761, y=0.3004, Y=0.1847), ColourChecker_InxxY(index=4, name=u'foliage', x=0.37, y=0.4501, Y=0.1335), ColourChecker_InxxY(index=5, name=u'blue flower', x=0.302, y=0.2877, Y=0.2324), ColourChecker_InxxY(index=6, name=u'bluish green', x=0.2856, y=0.391, Y=0.4174), ColourChecker_InxxY(index=7, name=u'orange', x=0.5291, y=0.4075, Y=0.3117), ColourChecker_InxxY(index=8, name=u'purplish blue', x=0.2339, y=0.2155, Y=0.114), ColourChecker_InxxY(index=9, name=u'moderate red', x=0.5008, y=0.3293, Y=0.1979), ColourChecker_InxxY(index=10, name=u'purple', x=0.3326, y=0.2556, Y=0.0644), ColourChecker_InxxY(index=11, name=u'yellow green', x=0.3989, y=0.4998, Y=0.4435), ColourChecker_InxxY(index=12, name=u'orange yellow', x=0.4962, y=0.4428, Y=0.4358), ColourChecker_InxxY(index=13, name=u'blue', x=0.204, y=0.1696, Y=0.0579), ColourChecker_InxxY(index=14, name=u'green', x=0.327, y=0.5033, Y=0.2307), ColourChecker_InxxY(index=15, name=u'red', x=0.5709, y=0.3298, Y=0.1268), ColourChecker_InxxY(index=16, name=u'yellow', x=0.4694, y=0.4732, Y=0.6081), ColourChecker_InxxY(index=17, name=u'magenta', x=0.4177, y=0.2704, Y=0.2007), ColourChecker_InxxY(index=18, name=u'cyan', x=0.2151, y=0.3037, Y=0.1903), ColourChecker_InxxY(index=19, name=u'white 9.5 (.05 D)', x=0.3488, y=0.3628, Y=0.9129), ColourChecker_InxxY(index=20, name=u'neutral 8 (.23 D)', x=0.3451, y=0.3596, Y=0.5885), ColourChecker_InxxY(index=21, name=u'neutral 6.5 (.44 D)', x=0.3446, y=0.359, Y=0.3595), ColourChecker_InxxY(index=22, name=u'neutral 5 (.70 D)', x=0.3438, y=0.3589, Y=0.1912), ColourChecker_InxxY(index=23, name=u'neutral 3.5 (1.05 D)', x=0.3423, y=0.3576, Y=0.0893), ColourChecker_InxxY(index=24, name=u'black 2 (1.5 D)', x=0.3439, y=0.3565, Y=0.032)]

  Average data derived from measurements of 30 ColourChecker charts.

  BABELCOLOR_AVERAGE : list

`colour.characterisation.dataset.colour_checkers.chromaticity_coordinates.` `COLORCHECKER_2005_ILLUMINANT` = (0.34567, 0.3585)

  ColorChecker 2005 illuminant.

  COLORCHECKER_2005_ILLUMINANT : tuple

`colour.characterisation.dataset.colour_checkers.chromaticity_coordinates.` `COLORCHECKER_2005` = [ColourChecker_InxxY(index=1, name=u'dark skin', x=0.4316, y=0.3777, Y=0.1008), ColourChecker_InxxY(index=2, name=u'light skin', x=0.4197, y=0.3744, Y=0.3495), ColourChecker_InxxY(index=3, name=u'blue sky', x=0.276, y=0.3016, Y=0.1836), ColourChecker_InxxY(index=4, name=u'foliage', x=0.3703, y=0.4499, Y=0.1325), ColourChecker_InxxY(index=5, name=u'blue flower', x=0.2999, y=0.2856, Y=0.2304), ColourChecker_InxxY(index=6, name=u'bluish green', x=0.2848, y=0.3911, Y=0.4178), ColourChecker_InxxY(index=7, name=u'orange', x=0.5295, y=0.4055, Y=0.3118), ColourChecker_InxxY(index=8, name=u'purplish blue', x=0.2305, y=0.2106, Y=0.1126), ColourChecker_InxxY(index=9, name=u'moderate red', x=0.5012, y=0.3273, Y=0.1938), ColourChecker_InxxY(index=10, name=u'purple', x=0.3319, y=0.2482, Y=0.0637), ColourChecker_InxxY(index=11, name=u'yellow green', x=0.3984, y=0.5008, Y=0.4446), ColourChecker_InxxY(index=12, name=u'orange yellow', x=0.4957, y=0.4427, Y=0.4357), ColourChecker_InxxY(index=13, name=u'blue', x=0.2018, y=0.1692, Y=0.0575), ColourChecker_InxxY(index=14, name=u'green', x=0.3253, y=0.5032, Y=0.2318), ColourChecker_InxxY(index=15, name=u'red', x=0.5686, y=0.3303, Y=0.1257), ColourChecker_InxxY(index=16, name=u'yellow', x=0.4697, y=0.4734, Y=0.5981), ColourChecker_InxxY(index=17, name=u'magenta', x=0.4159, y=0.2688, Y=0.2009), ColourChecker_InxxY(index=18, name=u'cyan', x=0.2131, y=0.3023, Y=0.193), ColourChecker_InxxY(index=19, name=u'white 9.5 (.05 D)', x=0.3469, y=0.3608, Y=0.9131), ColourChecker_InxxY(index=20, name=u'neutral 8 (.23 D)', x=0.344, y=0.3584, Y=0.5894), ColourChecker_InxxY(index=21, name=u'neutral 6.5 (.44 D)', x=0.3432, y=0.3581, Y=0.3632), ColourChecker_InxxY(index=22, name=u'neutral 5 (.70 D)', x=0.3446, y=0.3579, Y=0.1915), ColourChecker_InxxY(index=23, name=u'neutral 3.5 (1.05 D)', x=0.3401, y=0.3548, Y=0.0883), ColourChecker_InxxY(index=24, name=u'black 2 (1.5 D)', x=0.3406, y=0.3537, Y=0.0311)]

  Reference data from GretagMacbeth published in 2005.

  COLORCHECKER_2005 : list

`colour.characterisation.dataset.colour_checkers.chromaticity_coordinates.` `COLORCHECKER_1976_ILLUMINANT` = (0.31006, 0.31616)

  ColorChecker 1976 illuminant.

  COLORCHECKER_1976_ILLUMINANT : tuple

`colour.characterisation.dataset.colour_checkers.chromaticity_coordinates.` `COLORCHECKER_1976` = [ColourChecker_InxxY(index=1, name=u'dark skin', x=0.4002, y=0.3504, Y=0.1005), ColourChecker_InxxY(index=2, name=u'light skin', x=0.3773, y=0.3446, Y=0.3582), ColourChecker_InxxY(index=3, name=u'blue sky', x=0.247, y=0.2514, Y=0.1933), ColourChecker_InxxY(index=4, name=u'foliage', x=0.3372, y=0.422, Y=0.1329), ColourChecker_InxxY(index=5, name=u'blue flower', x=0.2651, y=0.24, Y=0.2427), ColourChecker_InxxY(index=6, name=u'bluish green', x=0.2608, y=0.343, Y=0.4306), ColourChecker_InxxY(index=7, name=u'orange', x=0.506, y=0.407, Y=0.3005), ColourChecker_InxxY(index=8, name=u'purplish blue', x=0.211, y=0.175, Y=0.12), ColourChecker_InxxY(index=9, name=u'moderate red', x=0.4533, y=0.3058, Y=0.1977), ColourChecker_InxxY(index=10, name=u'purple', x=0.2845, y=0.202, Y=0.0656), ColourChecker_InxxY(index=11, name=u'yellow green', x=0.38, y=0.4887, Y=0.4429), ColourChecker_InxxY(index=12, name=u'orange yellow', x=0.4729, y=0.4375, Y=0.4306), ColourChecker_InxxY(index=13, name=u'blue', x=0.1866, y=0.1285, Y=0.0611), ColourChecker_InxxY(index=14, name=u'green', x=0.3046, y=0.4782, Y=0.2339), ColourChecker_InxxY(index=15, name=u'red', x=0.5385, y=0.3129, Y=0.12), ColourChecker_InxxY(index=16, name=u'yellow', x=0.448, y=0.4703, Y=0.591), ColourChecker_InxxY(index=17, name=u'magenta', x=0.3635, y=0.2325, Y=0.1977), ColourChecker_InxxY(index=18, name=u'cyan', x=0.1958, y=0.2519, Y=0.1977), ColourChecker_InxxY(index=19, name=u'white 9.5 (.05 D)', x=0.3101, y=0.3163, Y=0.9001), ColourChecker_InxxY(index=20, name=u'neutral 8 (.23 D)', x=0.3101, y=0.3163, Y=0.591), ColourChecker_InxxY(index=21, name=u'neutral 6.5 (.44 D)', x=0.3101, y=0.3163, Y=0.362), ColourChecker_InxxY(index=22, name=u'neutral 5 (.70 D)', x=0.3101, y=0.3163, Y=0.1977), ColourChecker_InxxY(index=23, name=u'neutral 3.5 (1.05 D)', x=0.3101, y=0.3163, Y=0.09), ColourChecker_InxxY(index=24, name=u'black 2 (1.5 D)', x=0.3101, y=0.3163, Y=0.0313)]

  ColourChecker developed by McCamy and Al. at Macbeth, a Division of Kollmorgen.

  COLORCHECKER_1976 : list

`colour.characterisation.dataset.colour_checkers.chromaticity_coordinates.` `COLOURCHECKERS` = CaseInsensitiveMapping({u'ColorChecker 2005': ColourChecker(name=u'ColorChecker 2005', data=[ColourChecker_InxxY(index=1, name=u'dark skin', x=0.4316, y=0.3777, Y=0.1008), ColourChecker_InxxY(index=2, name=u'light skin', x=0.4197, y=0.3744, Y=0.3495), ColourChecker_InxxY(index=3, name=u'blue sky', x=0.276, y=0.3016, Y=0.1836), ColourChecker_InxxY(index=4, name=u'foliage', x=0.3703, y=0.4499, Y=0.1325), ColourChecker_InxxY(index=5, name=u'blue flower', x=0.2999, y=0.2856, Y=0.2304), ColourChecker_InxxY(index=6, name=u'bluish green', x=0.2848, y=0.3911, Y=0.4178), ColourChecker_InxxY(index=7, name=u'orange', x=0.5295, y=0.4055, Y=0.3118), ColourChecker_InxxY(index=8, name=u'purplish blue', x=0.2305, y=0.2106, Y=0.1126), ColourChecker_InxxY(index=9, name=u'moderate red', x=0.5012, y=0.3273, Y=0.1938), ColourChecker_InxxY(index=10, name=u'purple', x=0.3319, y=0.2482, Y=0.0637), ColourChecker_InxxY(index=11, name=u'yellow green', x=0.3984, y=0.5008, Y=0.4446), ColourChecker_InxxY(index=12, name=u'orange yellow', x=0.4957, y=0.4427, Y=0.4357), ColourChecker_InxxY(index=13, name=u'blue', x=0.2018, y=0.1692, Y=0.0575), ColourChecker_InxxY(index=14, name=u'green', x=0.3253, y=0.5032, Y=0.2318), ColourChecker_InxxY(index=15, name=u'red', x=0.5686, y=0.3303, Y=0.1257), ColourChecker_InxxY(index=16, name=u'yellow', x=0.4697, y=0.4734, Y=0.5981), ColourChecker_InxxY(index=17, name=u'magenta', x=0.4159, y=0.2688, Y=0.2009), ColourChecker_InxxY(index=18, name=u'cyan', x=0.2131, y=0.3023, Y=0.193), ColourChecker_InxxY(index=19, name=u'white 9.5 (.05 D)', x=0.3469, y=0.3608, Y=0.9131), ColourChecker_InxxY(index=20, name=u'neutral 8 (.23 D)', x=0.344, y=0.3584, Y=0.5894), ColourChecker_InxxY(index=21, name=u'neutral 6.5 (.44 D)', x=0.3432, y=0.3581, Y=0.3632), ColourChecker_InxxY(index=22, name=u'neutral 5 (.70 D)', x=0.3446, y=0.3579, Y=0.1915), ColourChecker_InxxY(index=23, name=u'neutral 3.5 (1.05 D)', x=0.3401, y=0.3548, Y=0.0883), ColourChecker_InxxY(index=24, name=u'black 2 (1.5 D)', x=0.3406, y=0.3537, Y=0.0311)], illuminant=(0.34567, 0.3585)), u'babel_average': ColourChecker(name=u'BabelColor Average', data=[ColourChecker_InxxY(index=1, name=u'dark skin', x=0.4325, y=0.3788, Y=0.1034), ColourChecker_InxxY(index=2, name=u'light skin', x=0.4191, y=0.3748, Y=0.3525), ColourChecker_InxxY(index=3, name=u'blue sky', x=0.2761, y=0.3004, Y=0.1847), ColourChecker_InxxY(index=4, name=u'foliage', x=0.37, y=0.4501, Y=0.1335), ColourChecker_InxxY(index=5, name=u'blue flower', x=0.302, y=0.2877, Y=0.2324), ColourChecker_InxxY(index=6, name=u'bluish green', x=0.2856, y=0.391, Y=0.4174), ColourChecker_InxxY(index=7, name=u'orange', x=0.5291, y=0.4075, Y=0.3117), ColourChecker_InxxY(index=8, name=u'purplish blue', x=0.2339, y=0.2155, Y=0.114), ColourChecker_InxxY(index=9, name=u'moderate red', x=0.5008, y=0.3293, Y=0.1979), ColourChecker_InxxY(index=10, name=u'purple', x=0.3326, y=0.2556, Y=0.0644), ColourChecker_InxxY(index=11, name=u'yellow green', x=0.3989, y=0.4998, Y=0.4435), ColourChecker_InxxY(index=12, name=u'orange yellow', x=0.4962, y=0.4428, Y=0.4358), ColourChecker_InxxY(index=13, name=u'blue', x=0.204, y=0.1696, Y=0.0579), ColourChecker_InxxY(index=14, name=u'green', x=0.327, y=0.5033, Y=0.2307), ColourChecker_InxxY(index=15, name=u'red', x=0.5709, y=0.3298, Y=0.1268), ColourChecker_InxxY(index=16, name=u'yellow', x=0.4694, y=0.4732, Y=0.6081), ColourChecker_InxxY(index=17, name=u'magenta', x=0.4177, y=0.2704, Y=0.2007), ColourChecker_InxxY(index=18, name=u'cyan', x=0.2151, y=0.3037, Y=0.1903), ColourChecker_InxxY(index=19, name=u'white 9.5 (.05 D)', x=0.3488, y=0.3628, Y=0.9129), ColourChecker_InxxY(index=20, name=u'neutral 8 (.23 D)', x=0.3451, y=0.3596, Y=0.5885), ColourChecker_InxxY(index=21, name=u'neutral 6.5 (.44 D)', x=0.3446, y=0.359, Y=0.3595), ColourChecker_InxxY(index=22, name=u'neutral 5 (.70 D)', x=0.3438, y=0.3589, Y=0.1912), ColourChecker_InxxY(index=23, name=u'neutral 3.5 (1.05 D)', x=0.3423, y=0.3576, Y=0.0893), ColourChecker_InxxY(index=24, name=u'black 2 (1.5 D)', x=0.3439, y=0.3565, Y=0.032)], illuminant=(0.34567, 0.3585)), u'ColorChecker 1976': ColourChecker(name=u'ColorChecker 1976', data=[ColourChecker_InxxY(index=1, name=u'dark skin', x=0.4002, y=0.3504, Y=0.1005), ColourChecker_InxxY(index=2, name=u'light skin', x=0.3773, y=0.3446, Y=0.3582), ColourChecker_InxxY(index=3, name=u'blue sky', x=0.247, y=0.2514, Y=0.1933), ColourChecker_InxxY(index=4, name=u'foliage', x=0.3372, y=0.422, Y=0.1329), ColourChecker_InxxY(index=5, name=u'blue flower', x=0.2651, y=0.24, Y=0.2427), ColourChecker_InxxY(index=6, name=u'bluish green', x=0.2608, y=0.343, Y=0.4306), ColourChecker_InxxY(index=7, name=u'orange', x=0.506, y=0.407, Y=0.3005), ColourChecker_InxxY(index=8, name=u'purplish blue', x=0.211, y=0.175, Y=0.12), ColourChecker_InxxY(index=9, name=u'moderate red', x=0.4533, y=0.3058, Y=0.1977), ColourChecker_InxxY(index=10, name=u'purple', x=0.2845, y=0.202, Y=0.0656), ColourChecker_InxxY(index=11, name=u'yellow green', x=0.38, y=0.4887, Y=0.4429), ColourChecker_InxxY(index=12, name=u'orange yellow', x=0.4729, y=0.4375, Y=0.4306), ColourChecker_InxxY(index=13, name=u'blue', x=0.1866, y=0.1285, Y=0.0611), ColourChecker_InxxY(index=14, name=u'green', x=0.3046, y=0.4782, Y=0.2339), ColourChecker_InxxY(index=15, name=u'red', x=0.5385, y=0.3129, Y=0.12), ColourChecker_InxxY(index=16, name=u'yellow', x=0.448, y=0.4703, Y=0.591), ColourChecker_InxxY(index=17, name=u'magenta', x=0.3635, y=0.2325, Y=0.1977), ColourChecker_InxxY(index=18, name=u'cyan', x=0.1958, y=0.2519, Y=0.1977), ColourChecker_InxxY(index=19, name=u'white 9.5 (.05 D)', x=0.3101, y=0.3163, Y=0.9001), ColourChecker_InxxY(index=20, name=u'neutral 8 (.23 D)', x=0.3101, y=0.3163, Y=0.591), ColourChecker_InxxY(index=21, name=u'neutral 6.5 (.44 D)', x=0.3101, y=0.3163, Y=0.362), ColourChecker_InxxY(index=22, name=u'neutral 5 (.70 D)', x=0.3101, y=0.3163, Y=0.1977), ColourChecker_InxxY(index=23, name=u'neutral 3.5 (1.05 D)', x=0.3101, y=0.3163, Y=0.09), ColourChecker_InxxY(index=24, name=u'black 2 (1.5 D)', x=0.3101, y=0.3163, Y=0.0313)], illuminant=(0.31006, 0.31616)), u'BabelColor Average': ColourChecker(name=u'BabelColor Average', data=[ColourChecker_InxxY(index=1, name=u'dark skin', x=0.4325, y=0.3788, Y=0.1034), ColourChecker_InxxY(index=2, name=u'light skin', x=0.4191, y=0.3748, Y=0.3525), ColourChecker_InxxY(index=3, name=u'blue sky', x=0.2761, y=0.3004, Y=0.1847), ColourChecker_InxxY(index=4, name=u'foliage', x=0.37, y=0.4501, Y=0.1335), ColourChecker_InxxY(index=5, name=u'blue flower', x=0.302, y=0.2877, Y=0.2324), ColourChecker_InxxY(index=6, name=u'bluish green', x=0.2856, y=0.391, Y=0.4174), ColourChecker_InxxY(index=7, name=u'orange', x=0.5291, y=0.4075, Y=0.3117), ColourChecker_InxxY(index=8, name=u'purplish blue', x=0.2339, y=0.2155, Y=0.114), ColourChecker_InxxY(index=9, name=u'moderate red', x=0.5008, y=0.3293, Y=0.1979), ColourChecker_InxxY(index=10, name=u'purple', x=0.3326, y=0.2556, Y=0.0644), ColourChecker_InxxY(index=11, name=u'yellow green', x=0.3989, y=0.4998, Y=0.4435), ColourChecker_InxxY(index=12, name=u'orange yellow', x=0.4962, y=0.4428, Y=0.4358), ColourChecker_InxxY(index=13, name=u'blue', x=0.204, y=0.1696, Y=0.0579), ColourChecker_InxxY(index=14, name=u'green', x=0.327, y=0.5033, Y=0.2307), ColourChecker_InxxY(index=15, name=u'red', x=0.5709, y=0.3298, Y=0.1268), ColourChecker_InxxY(index=16, name=u'yellow', x=0.4694, y=0.4732, Y=0.6081), ColourChecker_InxxY(index=17, name=u'magenta', x=0.4177, y=0.2704, Y=0.2007), ColourChecker_InxxY(index=18, name=u'cyan', x=0.2151, y=0.3037, Y=0.1903), ColourChecker_InxxY(index=19, name=u'white 9.5 (.05 D)', x=0.3488, y=0.3628, Y=0.9129), ColourChecker_InxxY(index=20, name=u'neutral 8 (.23 D)', x=0.3451, y=0.3596, Y=0.5885), ColourChecker_InxxY(index=21, name=u'neutral 6.5 (.44 D)', x=0.3446, y=0.359, Y=0.3595), ColourChecker_InxxY(index=22, name=u'neutral 5 (.70 D)', x=0.3438, y=0.3589, Y=0.1912), ColourChecker_InxxY(index=23, name=u'neutral 3.5 (1.05 D)', x=0.3423, y=0.3576, Y=0.0893), ColourChecker_InxxY(index=24, name=u'black 2 (1.5 D)', x=0.3439, y=0.3565, Y=0.032)], illuminant=(0.34567, 0.3585)), u'cc2005': ColourChecker(name=u'ColorChecker 2005', data=[ColourChecker_InxxY(index=1, name=u'dark skin', x=0.4316, y=0.3777, Y=0.1008), ColourChecker_InxxY(index=2, name=u'light skin', x=0.4197, y=0.3744, Y=0.3495), ColourChecker_InxxY(index=3, name=u'blue sky', x=0.276, y=0.3016, Y=0.1836), ColourChecker_InxxY(index=4, name=u'foliage', x=0.3703, y=0.4499, Y=0.1325), ColourChecker_InxxY(index=5, name=u'blue flower', x=0.2999, y=0.2856, Y=0.2304), ColourChecker_InxxY(index=6, name=u'bluish green', x=0.2848, y=0.3911, Y=0.4178), ColourChecker_InxxY(index=7, name=u'orange', x=0.5295, y=0.4055, Y=0.3118), ColourChecker_InxxY(index=8, name=u'purplish blue', x=0.2305, y=0.2106, Y=0.1126), ColourChecker_InxxY(index=9, name=u'moderate red', x=0.5012, y=0.3273, Y=0.1938), ColourChecker_InxxY(index=10, name=u'purple', x=0.3319, y=0.2482, Y=0.0637), ColourChecker_InxxY(index=11, name=u'yellow green', x=0.3984, y=0.5008, Y=0.4446), ColourChecker_InxxY(index=12, name=u'orange yellow', x=0.4957, y=0.4427, Y=0.4357), ColourChecker_InxxY(index=13, name=u'blue', x=0.2018, y=0.1692, Y=0.0575), ColourChecker_InxxY(index=14, name=u'green', x=0.3253, y=0.5032, Y=0.2318), ColourChecker_InxxY(index=15, name=u'red', x=0.5686, y=0.3303, Y=0.1257), ColourChecker_InxxY(index=16, name=u'yellow', x=0.4697, y=0.4734, Y=0.5981), ColourChecker_InxxY(index=17, name=u'magenta', x=0.4159, y=0.2688, Y=0.2009), ColourChecker_InxxY(index=18, name=u'cyan', x=0.2131, y=0.3023, Y=0.193), ColourChecker_InxxY(index=19, name=u'white 9.5 (.05 D)', x=0.3469, y=0.3608, Y=0.9131), ColourChecker_InxxY(index=20, name=u'neutral 8 (.23 D)', x=0.344, y=0.3584, Y=0.5894), ColourChecker_InxxY(index=21, name=u'neutral 6.5 (.44 D)', x=0.3432, y=0.3581, Y=0.3632), ColourChecker_InxxY(index=22, name=u'neutral 5 (.70 D)', x=0.3446, y=0.3579, Y=0.1915), ColourChecker_InxxY(index=23, name=u'neutral 3.5 (1.05 D)', x=0.3401, y=0.3548, Y=0.0883), ColourChecker_InxxY(index=24, name=u'black 2 (1.5 D)', x=0.3406, y=0.3537, Y=0.0311)], illuminant=(0.34567, 0.3585))})

  Aggregated ColourCheckers chromaticity coordinates.

  COLOURCHECKERS : dict
    (‘BabelColor Average’, ‘ColorChecker 2005’, ‘ColorChecker 1976’)

  Aliases:

  - ‘babel_average’: ‘BabelColor Average’
  - ‘cc2005’: ‘ColorChecker 2005’